# Copyright 2014, 2015 Paul Hänsch
#
# This file is part of Confetti.
# 
# Confetti is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# 
# Confetti is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with Confetti.  If not, see <http://www.gnu.org/licenses/>. 

check_gen() {
  [ "$values[GENDER]" = "$1" ] && echo 'selected="selected"'
}
check_a() {
  egrep -q "^${1}.${id}$" "$_DATA/mappings/attendance" && echo 'checked="checked"'
}

n_last="$(echo "$values[N]" |sed -rn 's:^([^;]*;){0} *([^;]*).*$:\2:p')"
n_first="$(echo "$values[N]" |sed -rn 's:^([^;]*;){1} *([^;]*).*$:\2:p')"
n_middle="$(echo "$values[N]" |sed -rn 's:^([^;]*;){2} *([^;]*).*$:\2:p')"
n_pre="$(echo "$values[N]" |sed -rn 's:^([^;]*;){3} *([^;]*).*$:\2:p')"
n_post="$(echo "$values[N]" |sed -rn 's:^([^;]*;){4} *([^;]*)*$:\2:p')"

SUP_FIELDS=(N NICKNAME GENDER BDAY X-ZACK-JOINDATE X-ZACK-LEAVEDATE EMAIL TEL IMPP ADR URL NOTE)

[ -z "$values[UID]" ] && values[UID]="$(uuidgenerator)"

cat <<END_HTML
<form id="$id" class="card" action="?action=update_card" method="POST">
  <input type="hidden" name="card" value="${id}"/>
  <div class="section basic">
    <h3>$(l10n N)</h3>
    <input class="item N" name="3N" placeholder="$(l10n n_pre)" value="$n_pre" />
    <input class="item N" name="1N" placeholder="$(l10n n_first)" value="$n_first" />
    <input class="item N" name="2N" placeholder="$(l10n n_middle)" value="$n_middle" />
    <input class="item N" name="0N" placeholder="$(l10n n_last)" value="$n_last" />
    <input class="item N" name="4N" placeholder="$(l10n n_post)" value="$n_post" />

    <select class="item GENDER" name="GENDER">
      <option value="" disabled="disabled">$(l10n GENDER)</option>
      <option value="female" $(check_gen female)>$(l10n gender_female)</option>
      <option value="male" $(check_gen male)>$(l10n gender_male)</option>
      <option value="other" $(check_gen other)>$(l10n gender_other)</option>
      <option value="none" $(check_gen none)>$(l10n gender_none)</option>
    </select>

    $(for n in NICKNAME NICKNAME{0..10}; do
      echo "${values[$n]:+<input class="item NICKNAME" name="NICKNAME" placeholder="$(l10n NICKNAME)" value="$values[$n]" />}"
    done)

    <h3>$(l10n BDAY)</h3>
    <input class="item BDAY" name="BDAY" value="$values[BDAY]" />

    <h3>$(l10n X-ZACK-JOINDATE)</h3>
    <input class="item X-ZACK-LEAVEDATE" name="X-ZACK-JOINDATE" value="$values[X-ZACK-JOINDATE]" />
    $(if [ -n "$values[X-ZACK-LEAVEDATE]" ]; then
      echo '    <h3>'$(l10n X-ZACK-LEAVEDATE)'</h3>'
      echo '    <input class="item X-ZACK-LEAVEDATE" name="X-ZACK-LEAVEDATE" value="'$values[X-ZACK-LEAVEDATE]'" />'
    fi)

    $(if [ -n "$values[SOUND]" ]; then
      echo '    <audio controls="controls" class="item SOUND">'
      echo '      <source type="audio/ogg" src="data:audio/ogg;base64,'$values[SOUND]'" />'
      echo '    </audio>'
    fi)
    ${values[PHOTO]:+<img class="item PHOTO" src="data:image/$tags[PHOTO_TYPE];base64,$values[PHOTO]" />}
    ${values[LOGO]:+<img class="item LOGO" src="data:image/$tags[LOGO_TYPE];base64,$values[LOGO]" />}
  </div>

  <div class="section phone">
    <h3>$(l10n TEL)</h3>
    <input class="item TEL" name="TEL" value="$values[TEL]" />
    $(for n in TEL{0..10}; do
      echo "${values[$n]:+<input class="item TEL" name="TEL" value="'$values[$n]'" />}"
    done)
  </div>

  <div class="section message">
    <h3>$(l10n EMAIL)</h3>
    <input class="item EMAIL" name="EMAIL" value="$values[EMAIL]" />
    $(for n in EMAIL{0..10}; do
      echo "${values[$n]:+<input class="item EMAIL" name="EMAIL" value="$values[$n]" />}"
    done)
    ${values[IMPP]:+<h3>$(l10n IMPP)</h3>}
    $(for n in IMPP IMPP{0..10}; do
      echo "${values[$n]:+<input class="item IMPP" name="IMPP" value="$values[$n]" />}"
    done)
  </div>

  <div class="section address">
    <h3>$(l10n ADR)</h3>
    <textarea class="item ADR" name="ADR">$values[ADR]</textarea>
    $(for n in ADR{0..10}; do
      echo "${values[$n]:+<textarea class="item ADR" name="ADR">$values[$n]</textarea>}"
    done)
    ${values[URL]:+<h3>$(l10n URL)</h3>}
    $(for n in URL URL{0..10}; do
      echo "${values[$n]:+<input class="item URL" name="URL" value="$values[$n]" />}"
    done)
  </div>

  <div class="section note">
    <h3>$(l10n NOTE)</h3>
    <textarea class="item NOTE" name="NOTE">$values[NOTE]</textarea>
    $(for n in NOTE{0..10}; do
      echo "${values[$n]:+<textarea class="item NOTE" name="NOTE">$values[$n]</textarea>}"
    done)
  </div>

  <div class="section attendance">
    <h3>$(l10n course_attendance)</h3>
    $(listcourses |while read each; do
      cname="$(sed -rn 's:^SUMMARY\:(.*)$:\1:p' "$_DATA/ical/$each")"
      echo '<label><input type="checkbox" name="attendance" value="'$each'" '$(check_a "$each")'/>'$cname'</label>'
    done)
  </div>

  <div class="control">
    <select class="item" name="newfield">
      <option value="" disabled="disabled" selected="selected">$(l10n edit_addfieldtext)</option>
      $(for f in $SUP_FIELDS; do echo "<option value=\"$f\">$(l10n $f)</option>"; done)
    </select
    ><button class="item" type="submit" name="action" value="addfield">$(l10n edit_addfield)</button>
    <button class="item" type="submit" name="action" value="update">$(l10n edit_update)</button>
    <button class="item" type="submit" name="action" value="delete">$(l10n edit_delete)</button>
    <button class="item" type="submit" name="action" value="cancel">$(l10n edit_cancel)</button>
  </div>
  <input type="hidden" name="UID" value="$values[UID]"/>
</form>
END_HTML
